@@ -34,7 +34,12 @@ angular.module('monitoring.controllers', [])
         $scope.metrics = metricsList;
         $scope.metricNames = uniqueNames(metricsList, 'name')
         $scope.currentMetric = $scope.metricNames[0];
-        $scope.possibleDimensions = function() {
+        $scope.currentFunction = "max";
+        $scope.currentComparator = ">";
+        $scope.currentThreshold = 0;
+        $scope.matchingMetrics= [];
+        $scope.tags = [];
+        $scope.possibleDimensions = function(query) {
             var deferred = $q.defer();
             var dim = {}
             var dimList = []
@@ -42,7 +47,9 @@ angular.module('monitoring.controllers', [])
                 for (var key in value.dimensions) {
                     if (value.dimensions.hasOwnProperty(key)) {
                         var dimStr = key + "=" + value.dimensions[key]
-                        dim[dimStr] = dimStr
+                        if (dimStr.indexOf(query) === 0) {
+                            dim[dimStr] = dimStr;
+                        }
                     }
                 }
             });
@@ -65,7 +72,7 @@ angular.module('monitoring.controllers', [])
             angular.forEach($scope.metrics, function(value, key) {
                 if (value.name === $scope.currentMetric) {
                     var match = true;
-                    for (var i =0; i < $scope.tags.length; i++) {
+                    for (var i = 0; i < $scope.tags.length; i++) {
                         var vals = $scope.tags[i]['text'].split('=');
                         if (value.dimensions[vals[0]] !== vals[1]) {
                             match = false;
@@ -79,7 +86,8 @@ angular.module('monitoring.controllers', [])
             });
             $scope.matchingMetrics = mm
             $scope.dimnames = ['name', 'dimensions'];
-       }
+            $('#match').val($scope.formatMatchBy());
+        }
         $scope.formatDimension = function() {
             var dim = ''
             angular.forEach($scope.tags, function(value, key) {
@@ -88,7 +96,16 @@ angular.module('monitoring.controllers', [])
                 }
                 dim += value['text']
             })
-            return $scope.currentMetric + '{' + dim + '}';
+            return $scope.currentMetric + '{' + dim + '} ' + $scope.currentComparator + ' ' + $scope.currentThreshold;
+        }
+        $scope.formatMatchBy = function() {
+            var dimNames = {}
+            for (var i = 0; i < $scope.matchingMetrics.length; i++) {
+                for (var attrname in $scope.matchingMetrics[i].dimensions) { dimNames[attrname] = true; }
+            }
+            var matches = [];
+            for (var attrname in dimNames) { matches.push(attrname); }
+            return matches;
         }
         $scope.init = function(defaultTag) {
             if (defaultTag.length > 0) {
